c---------------------------------------------------------------------
C!F77-INC
c
c!Description:
c Main data include file for modis processing of the Direct Broadcast
c  Version of the Cloud Top Properties product (MOD06)
c
c!Input parameters: None.
c
c!Output Parameters: None.
c
c!Revision History:
c 
c Revision 01.00  1997/12/09 23:05:07
c Written by Kathy Strabala
c Original version.
c
c!Team-unique Header:
c
c!References and Credits:
c
c
c!END
c---------------------------------------------------------------------

c-----------------------------------------------------------------------
c ... Global Parameters
c-----------------------------------------------------------------------

c ... Maximum character size of input file name
      integer PATH_MAX
      parameter (PATH_MAX = 255)

c ... Number of bands in Direct Broadcast Output file 
      integer OUT_BAND
      parameter (OUT_BAND = 48)

c ... Maximum number of pixels and lines in a 1km scan

      integer max_pixel, MAX_LINE
      parameter( max_pixel = 1500, MAX_LINE = 10 )

c ... Sampling factor (for 5x5 sampling, isamp = 5)

      integer isamp
      parameter ( isamp = 5 )

c ... Maximum number of sampled pixels and lines in a 1km scan

      integer max_samp_pixel, max_samp_line
      parameter ( max_samp_pixel = max_pixel / isamp,
     &  max_samp_line = max_line / isamp )

c ... Total number of bands in input file
      integer INBAND
      parameter( INBAND = 36 )

c ... Number of 1km IR bands

      integer nbands
      parameter( nbands = 18 )

c ... Number of 1km IR bands to use as output
      integer n_output 
      parameter ( n_output = 7 )

c ... Bad data value

      real bad_value
      parameter( bad_value = -999.0 )

c ... Minimum number of good pixels allowed in each pixel sampling box

      integer min_ngood
      parameter ( min_ngood = 15 )

c ... Minimum number of good pixels allowed in each pixel sampling box
c ... for CO2-slicing processing

      integer min_ngoodct
      parameter ( min_ngoodct = 15 )

c ... Number of bytes per 1km pixel for cloud mask result and QA arrays

      integer nmask
      parameter( nmask = 6 )

c ... Number of atmospheric levels in output retrieval profiles

      integer outlevels
      parameter ( outlevels = 20 )

c ... Number of product QA bytes per 5x5 pixel box

      integer nproduct_qa
      parameter( nproduct_qa = 10 )

c ... Number of infrared water vapor QA bytes per 5x5 pixel box 
      integer nwater_vapor_qa
      parameter( nwater_vapor_qa = 5 )

c *** MOD_PR06IR additions **************************************
c ... Number of bands used for irphase processing
      integer irphase_band
      parameter ( irphase_band = 3 )

c ... Number of bands used for daytime phase processing
      integer dayphase_band
      parameter ( dayphase_band = 6 )
      
!**   Number of bands used for co2 slicing
      integer co2_band
      parameter ( co2_band = 6)

c ... Number of brightness temperature difference pairs
      integer phase_pairs
      parameter ( phase_pairs = 2 )

c ... Set scan angle process limit
      real Zen_Ang_Lim
      parameter(Zen_Ang_Lim = 65.0)

c ... Set output missing value for integer variables
      integer out_misg
      parameter(out_misg = -10000)

c ... Set output missing value for metadata information
      real META_MISG
      parameter (META_MISG = -99999.0)

c ... Set output clear indication value
      integer clr_data
      parameter(clr_data = -999)

c ... Set output clear indication value
      integer clr_misg
      parameter(clr_misg = 100)

c-----------------------------------------------------------------------
c ... REAL global variables stored in COMMON
c-----------------------------------------------------------------------

c ... MODIS L1B input radiance data for all 1km IR bands

      real radiance1( max_pixel, max_line, nbands )

c ... MODIS geolocation input latitude and longitude data for 1km bands

      real lat1( max_pixel, max_line ),
     &     lon1( max_pixel, max_line ),
     &     view( max_pixel, max_line ),
     &     solz( max_pixel, max_line )
      integer dn_flag( max_pixel, max_line )

c ... NCEP ancillary input surface temperature, water vapor mixing
c ... ratio, total ozone, and surface pressure for 1km bands

      real tem1( max_pixel, max_line ), wat1( max_pixel, max_line ),
     &  ozn1( max_pixel, max_line ), pre1( max_pixel, max_line )

c ### NCEP ancillary temperature and water vapor mixing ratio profiles
c ### at the 101 standard levels for 1km bands

      real tprof1( 101, max_pixel, max_line ),
     &  wprof1( 101, max_pixel, max_line )

c ### Stuff added by Rich for MOD_PR06CT

c ### MOD_PR06CT processing option

      integer mod06ct_proc_opt
      parameter ( mod06ct_proc_opt = 1 )

c ### Maximum number of CO2-slicing solutions

      integer max_solutns
      parameter (max_solutns = 5 )

c ### Number of input atmospheric levels

      integer plev
      parameter (plev = 101)

c ### Number of atmospheric levels in transmittance model

      integer tau_lev
      parameter (tau_lev = 101)

c ### Top level at which to begin interpolation of profiles.

      integer ltop
      parameter (ltop = 24)

c ### Bottom level at which to begin interpolation of profiles.

      integer lbot
      parameter (lbot = 34)

c ### Number of MODIS bands used in the CO2-slicing algorithm

      integer nbct
      parameter (nbct = 5)

c ### Total numberr of MODIS bands needed for CO2-slicing algorithm

      integer ntbct
      parameter (ntbct = 6)

c ### Number of solutions in CO2-slicing algorithm

      integer nsct
      parameter (nsct = 4)

c ### Array index corresponding to the 11 um MODIS data

      integer kwc
      parameter (kwc = 5)

c ### Array index corresponding to the 8.5 um MODIS data

      integer kwv
      parameter (kwv = 6)

c ### Number of cloudy pixels in a box needed to generate
c ### cloud top products

      integer ncprct
      parameter (ncprct = 4)

c ### Number pixels to average to obtain "cold" and "warm"
c ### radiances (processing option 2 only)

      integer n_avgct
      parameter (n_avgct = 4)

c ### MOD_PR06CT Clear-sky bias correction array

      real cs_bias_corr( max_pixel, max_line, nbct )


c ... common output products at 5x5 sampling resolution

      real brightness_temp( max_samp_pixel, max_samp_line, n_output ),
     &  sfc_temp( max_samp_pixel, max_samp_line ),
     &  sfc_pres( max_samp_pixel, max_samp_line )

c ### MOD_PR06CT output products at 5x5 sampling resolution

      real processing_flag( max_samp_pixel, max_samp_line ),
     &  cloud_h_method( max_samp_pixel, max_samp_line ),
     &  cloudtop_pres( max_samp_pixel, max_samp_line ),
     &  cloudtop_temp( max_samp_pixel, max_samp_line ),
     &  height_tropopause( max_samp_pixel, max_samp_line ),
     &  cloud_fraction( max_samp_pixel, max_samp_line ),
     &  cloudtop_eff_emi( max_samp_pixel, max_samp_line ),
     &  cloudtop_pre_ir( max_samp_pixel, max_samp_line ),
     &  spec_cloud_forcing(max_samp_pixel, max_samp_line, max_solutns ),
     &  cloudtop_pres_from_ratios(max_samp_pixel, max_samp_line,
     &  max_solutns )

c *** MOD_PR06IR ouput products at 5x5 sampling resolution ****
      real brightness_diff( max_samp_pixel,max_samp_line,phase_pairs),
     &  radiance_variance( max_samp_pixel, max_samp_line,n_output ),
     &  cloud_phase( max_samp_pixel, max_samp_line ),
     &  surface_type( max_samp_pixel, max_samp_line )

c-----------------------------------------------------------------------
c ... INTEGER global variables stored in COMMON
c-----------------------------------------------------------------------

c ... Bad/Good data flag array for each pixel box (0=Bad, 1=Good)

      integer box_flag( isamp, isamp )
      integer box_flag_co2( isamp, isamp )
      integer box_flag_IR( isamp, isamp )
      integer box_flag_dayIR( isamp, isamp )

c ### Clear/Cloud data flag array for each pixel box (0=Clear, 1=Cloud)

      integer box_cloud( isamp, isamp )

c ... 1km IR band numbers

      integer bands( nbands )      

c ... Day night mode flag - needed for division of parameters into
c ...  day or night 
      integer day_night_flag( max_samp_pixel, max_samp_line )

c *** Additions for MOD_PR06IR ***************************************
      integer ir_aband( irphase_band )
      integer ir_mband( irphase_band )
c** Additions for CO2 slicing
      integer ir_co2band(co2_band)
      integer ir_co2bandptr(co2_band)
c** Additions for daytime cloud phase algorithm
      integer day_band(dayphase_band)
      integer day_bandptr(dayphase_band)

c ### Arrays holding i,j coordinates of met data for each pixel in a
c ### scan.

      integer met_data_i( max_pixel, max_line )
      integer met_data_j( max_pixel, max_line )
      
c-----------------------------------------------------------------------
c ... BYTE global variables stored in COMMON
c-----------------------------------------------------------------------

c ... Land/water mask for 1km bands

      byte land1( max_pixel, max_line )

c ... Ecosystem type for 1km bands

      byte eco ( max_pixel, max_line)

c ... Cloud mask result and QA arrays for 1km bands

      byte mask1( max_pixel, max_line )

c ... Product QA array at 5x5 sampling resolution

      byte product_qa( nproduct_qa, max_samp_pixel, max_samp_line )

c-----------------------------------------------------------------------
c ### COMMON block to hold global variables
c ### (Arrays are listed in the order REALs, INTEGERs, BYTEs)
c-----------------------------------------------------------------------

      common / mod06_data /
     &  radiance1,lat1,lon1,view,solz,tem1,wat1,ozn1,pre1,tprof1,
     &  wprof1, brightness_temp, sfc_temp, sfc_pres, cs_bias_corr,
     &  processing_flag, cloud_h_method, cloudtop_pres, cloudtop_temp,
     &  height_tropopause, cloud_fraction, cloudtop_eff_emi,
     &  cloudtop_pre_ir, spec_cloud_forcing, cloudtop_pres_from_ratios,
     &  brightness_diff, radiance_variance, cloud_phase, surface_type,
     &  box_flag, box_cloud, bands, ir_aband, ir_mband, dn_flag, 
     &  day_night_flag,
     &  ir_co2band, ir_co2bandptr, box_flag_co2, box_flag_IR,
     &  box_flag_dayIR, day_band, day_bandptr, met_data_i,
     &  met_data_j,land1,eco,mask1,product_qa
