C--------------------------------------------------------------------
C  Copyright (C) 2002,  Space Science and Engineering Center, 
C  University C  of Wisconsin-Madison, Madison WI.
C      
C  This program is free software; you can redistribute it 
C  and/or modify it under the terms of the GNU General 
C  Public License as published by the Free Software Foundation; 
C  either version 2 of the License, or (at your option) any 
C  later version.
C
C  This program is distributed in the hope that it will be 
C  useful, but WITHOUT ANY WARRANTY; without even the implied 
C  warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
C  See the  GNU General Public License for more details.
C
C  You should have received a copy of the GNU General Public 
C  License along with this program; if not, write to the Free 
C  Software Foundation, Inc., 59 Temple Place, Suite 330, 
C  Boston, MA  02111-1307 USA
C--------------------------------------------------------------------
C
C
      subroutine db_mod06CT_initialize_output( )
      
c-----------------------------------------------------------------------
c
c!F77
c
c!Description:
c    Initialize output product arrays for MOD06CT 5x5 sampling.
c
c!Input Parameters:
c   
c    None.
c
c!Output Parameters:
c
c    None.
c
c    The following arrays in COMMON /MOD06_DATA/ are initialized:
c    height_tropopause           tropopause height
c    cloud_h_method              index of method used to generate cloud
c                                  top height
c    cloudtop_pre_ir             cloud height from "window" channel only
c    spec_cloud_forcing          cloud - clear radiance difference
c    cloudtop_pres               cloud top pressure (hPa)
c    cloudtop_temp               cloud top temperature (K)
c    cloudtop_eff_emi            effective cloud emissivity
c    cloudtop_pres_from_ratios   cloud top pressure from all ratios(hPa)
c    processing_flag             flag indicating use of CO2 channel
c                                  ratios
c    cloud_fraction              cloud fraction from cloud mask
c
c!Revision History:
c
c!Team-unique Header:
c
c!End
c
c-----------------------------------------------------------------------

      implicit none
      save
          
      include 'db_mod06uw_data.inc'
      
c ... arguments - none

c ... local variables

      integer i, j, k

c ... Initialize all the output arrays

      do k = 1, max_solutns
        do j = 1, max_samp_line
          do i = 1, max_samp_pixel
            spec_cloud_forcing( i, j, k ) = bad_value
            cloudtop_pres_from_ratios( i, j, k ) = bad_value
          end do
        end do
      end do

      do j = 1, max_samp_line
        do i = 1, max_samp_pixel
          height_tropopause( i, j ) = bad_value
          cloud_h_method( i, j ) = bad_value
          cloudtop_pre_ir( i, j ) = bad_value
          cloudtop_pres( i, j ) = bad_value
          cloudtop_temp( i, j ) = bad_value
          cloudtop_eff_emi( i, j ) = bad_value
          processing_flag( i, j ) = bad_value
          cloud_fraction( i, j ) = bad_value

        end do
      end do                      

      return
      end
