C--------------------------------------------------------------------
C  Copyright (C) 2002,  Space Science and Engineering Center, 
C  University C  of Wisconsin-Madison, Madison WI.
C      
C  This program is free software; you can redistribute it 
C  and/or modify it under the terms of the GNU General 
C  Public License as published by the Free Software Foundation; 
C  either version 2 of the License, or (at your option) any 
C  later version.
C
C  This program is distributed in the hope that it will be 
C  useful, but WITHOUT ANY WARRANTY; without even the implied 
C  warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
C  See the  GNU General Public License for more details.
C
C  You should have received a copy of the GNU General Public 
C  License along with this program; if not, write to the Free 
C  Software Foundation, Inc., 59 Temple Place, Suite 330, 
C  Boston, MA  02111-1307 USA
C--------------------------------------------------------------------
C
C
      subroutine db_mod06_file_open( 
     &                                filename,
     &                                l1b_1km_neles,
     &                                eco_1km_lun,
     &                                l1b_1km_lun,
     &                                geo_1km_lun,
     &                                mask_lun,
     &                                scan_1km_lun,
     &                                anc_met_lun,
     &                                anc_sst_lun,
     &                                qa_lun,
     &                                mod06ct_lun,
     &                                hdr_lun,
     &                                qa_hdr_lun,
     &                                debug_lun
     &                              )
      implicit none
      save

      include 'cloudtop.inc'
      include 'db_mod06uw_data.inc'

C-----------------------------------------------------------------------
C!F77
C
C!DESCRIPTION:
c Program which will open files and return unit numbers for 
c all files used in the main DB Cloud Top Properties
c and cloud phase program. 
C
C!INPUT PARAMETERS:    None.
C
C!OUTPUT PARAMETERS:
C
C   filename           Configuration file name
C   l1b_1km_neles      Number of elements per scan line of data
C   eco_1km_lun        LUN for open 1km ecosystem file
C   l1b_1km_lun        LUN for open 1km L1B data file
C   geo_1km_lun        LUN for open geo file
C   mask_lun           LUN for open Cloud Mask file
C   scan_1km_lun       LUN for scan based metadata file
C   qa_lun             LUN for MOD06CT QA file
C   anc_met_lun        LUN for open met data file
C   anc_sst_lun        LUN for open Reynolds binary SST file
C   mod06ct_lun        LUN for MOD06CT output file
C   hdr_lun            LUN for MOD06CT output header file
C   qa_hdr_lun         LUN for MOD06CT QA header file
C   debug_lun          LUN for open debug messages file
C
C!REVISION HISTORY:
c
C!TEAM-UNIQUE HEADER:
C
C!REFERENCES AND CREDITS
C
C EXTERNALS:
C
C       NAMED CONSTANTS:
C
C       FUNCTIONS AND SUBROUTINES:
C               hdrgetkeystr.f
c               db_message.f
C
C!END-------------------------------------------------------------------

c --- constants
      character*18 FUNCTION
      parameter (FUNCTION = 'db_mod06_file_open')

c --- arguments
      integer l1b_1km_neles, eco_1km_lun, l1b_1km_lun, geo_1km_lun,
     +        scan_1km_lun, anc_met_lun, mask_lun, debug_lun, qa_lun,
     +        mod06ct_lun, hdr_lun, qa_hdr_lun, anc_sst_lun
      character*(*) filename

c --- external functions
      integer hdrgetkeystr

c --- internal variables
      character*12 req
      character*80 keyname
      character*(PATH_MAX) file
      integer len_file, keyindex, status, io_err, level, len
      logical  remove_all

c --- Common block used for writing debug output statements
      integer debug
      integer h_output
      common / bug / debug, h_output


c --- initialize the lun
      eco_1km_lun  = -1
      l1b_1km_lun  = -1
      geo_1km_lun  = -1
      mask_lun	   = -1
      scan_1km_lun = -1
      anc_met_lun  = -1
      anc_sst_lun  = -1
      qa_lun = -1
      debug_lun	= -1
      hdr_lun	= -1

      remove_all = .true.

c --- initialize dummy variables
      req = ' '
      file = ' '


C GLOBAL 1KM ECOSYSTEM FILE

c --- get the file requirement
      keyname = 'ECO_1KM_REQ'
      keyindex = 1
      status = hdrgetkeystr( filename, keyname, keyindex, req )
      if( status.lt.0 ) req = 'OPTIONAL'
      level = 3
      if( req(1:3).eq.'MAN' ) level = 2

c --- get file access information 
      keyname = 'ECO_1KM_NAME'
      keyindex = 1
      status = hdrgetkeystr( filename, keyname, keyindex, file )

c --- check for error reading info file
      if( status.lt.0 ) then 
         call message( 
     &                 FUNCTION,
     &                'FAILED - Read of 1km Ecosystem file name. ',
     &                 0, level 
     &               )

      else
                   
c ------ issue the OPEN request
         OPEN( 
     &         FILE=file,
     &         UNIT=ECO_1KM_UNIT,
     &         STATUS=ECO_1KM_STATUS,
     &         FORM=ECO_1KM_FORM,
     &         ACCESS=ECO_1KM_ACCESS,
     &         RECL=ECO_1KM_RECL,
     &         IOSTAT=io_err, 
     &         ERR=9001 
     &       ) 

         call message(
     &                 '--',
     &                'Using Ecosystem file: '// file ,
     &                 0, 4
     &               )

         eco_1km_lun = ECO_1KM_UNIT
         goto 100

c ------ Failed to open file (non-fatial)  
9001     continue 
         call message( 
     &                 FUNCTION,
     &                'FAILED - Could not open 1km ecosystem file.',
     &                 0, level 
     &               )


      endif
100   continue
      if( debug.ne.0 ) then
         call strcompress( file, remove_all, len_file )
         write(*,*) '  ecosystem 1km file: ',file(1:len_file)
      endif


C 1KM Level 1B MODIS DATA FILES

c --- get the file requirement
      keyname = 'L1B_1KM_REQ'
      keyindex = 1
      status = hdrgetkeystr( filename, keyname, keyindex, req )
      if( status.lt.0 ) req = 'OPTIONAL'
      level = 3
      if( req(1:3).eq.'MAN' ) level = 2

c --- get file access information 
      keyname = 'L1B_1KM_NAME'
      keyindex = 1
      status = hdrgetkeystr( filename, keyname, keyindex, file )

c --- check for error reading info file
      if( status.lt.0 ) then 
         call message( 
     &                 FUNCTION,
     &                'FAILED: Read of 1km file info . ',
     &                 0, level 
     &               )

      else
                   
c ------ issue the OPEN request
         OPEN( 
     &         FILE=file,
     &         UNIT=L1B_1KM_UNIT,
     &         FORM=L1B_1KM_FORM,
     &         ACCESS=L1B_1KM_ACCESS,
     &         STATUS=L1B_1KM_STATUS,
     &         RECL=l1b_1km_neles*4,
     &         IOSTAT=io_err, 
     &         ERR=9005
     &       ) 

         call message(
     &                 '--',
     &                'Using 1km L1B file: '// file ,
     &                 0, 4
     &               )

         l1b_1km_lun = L1B_1KM_UNIT
         goto 140

c ------ Failed to open 
9005     continue 
         call message( 
     &                 FUNCTION,
     &                'FAILED: Could not open 1km L1B file. ', 
     &                 0, level 
     &               )

      endif
140   continue
      if( debug.ne.0 ) then
         call strcompress( file, remove_all, len_file )
         write(*,*) '  L1B 1km file: ',file(1:len_file)
      endif
              


C GEOLOCATION FILES: LATITUDE, LONGITUDE, HEIGHT, ...

c --- get the file requirement
      keyname = 'GEO_1KM_REQ'
      keyindex = 1
      status = hdrgetkeystr( filename, keyname, keyindex, req )
      if( status.lt.0 ) req = 'OPTIONAL'
      level = 3
      if( req(1:3).eq.'MAN' ) level = 2

c --- get file access information 
      keyname = 'GEO_1KM_NAME'
      keyindex = 1
      status = hdrgetkeystr( filename, keyname, keyindex, file )

c --- check for error reading info file
      if( status.lt.0 ) then 
         call message( 
     &                 FUNCTION,
     &                'FAILED: Read of Geo file info . ',
     &                 0, level 
     &               )

      else
                   
c ------ issue the OPEN request
         OPEN( 
     &         FILE=file,
     &         UNIT=GEO_1KM_UNIT,
     &         STATUS=GEO_1KM_STATUS,
     &         FORM=GEO_1KM_FORM,
     &         ACCESS=GEO_1KM_ACCESS,
     &         RECL=l1b_1km_neles*4,
     &         IOSTAT=io_err, 
     &         ERR=9006
     &       ) 

         call message(
     &                 '--',
     &                'Using 1km GEO file: '// file ,
     &                 0, 4
     &               )

         geo_1km_lun = GEO_1KM_UNIT
         goto 150

c ------ Failed to open 
9006     continue 
         call message( 
     &                 FUNCTION,
     &                'FAILED: Could not open GEO file. ',
     &                 0, level 
     &               )

      endif
150   continue
      if( debug.ne.0 ) then
         call strcompress( file, remove_all, len_file )
         write(*,*) '  GEO file: ',file(1:len_file)
      endif
              


C SCAN METADATA FILE: TYPE, MIRROR SIDE

c --- get the file requirement
      keyname = 'SCAN_1KM_REQ'
      keyindex = 1
      status = hdrgetkeystr( filename, keyname, keyindex, req )
      if( status.lt.0 ) req = 'OPTIONAL'
      level = 3
      if( req(1:3).eq.'MAN' ) level = 2

c --- get file access information 
      keyname = 'SCAN_1KM_NAME'
      keyindex = 1
      status = hdrgetkeystr( filename, keyname, keyindex, file )

c --- check for error reading info file
      if( status.lt.0 ) then 
         call message( 
     &                 FUNCTION,
     &                'FAILED: Read of Scan Metadata file info . ',
     &                 0, level 
     &               )

      else

c ------ issue the OPEN request
         OPEN( 
     &         FILE=file,
     &         UNIT=SCAN_1KM_UNIT,
     &         STATUS=SCAN_1KM_STATUS,
     &         FORM=SCAN_1KM_FORM,
     &         ACCESS=SCAN_1KM_ACCESS,
     &         RECL=SCAN_1KM_RECL,
     &         IOSTAT=io_err, 
     &         ERR=9007
     &       ) 

         call message(
     &                 '--',
     &                'Using Meta file: '// file ,
     &                 0, 4
     &               )

         scan_1km_lun = SCAN_1KM_UNIT
         goto 160

c ------ Failed to open 
9007     continue 
         call message( 
     &                 FUNCTION,
     &                'FAILED: Could not open Scan Metadata file. ',
     &                 0, level 
     &               )

      endif
160   continue
      if( debug.ne.0 ) then
         call strcompress( file, remove_all, len_file )
         write(*,*) '  Scan Metadata file: ',file(1:len_file)
      endif
      
C ANCILLARY FILES: SST FILE

c --- get the file requirement
      keyname = 'OISST_REQ'
      keyindex = 1
      status = hdrgetkeystr( filename, keyname, keyindex, req )
      if( status.lt.0 ) req = 'OPTIONAL'
      level = 3
      if( req(1:3).eq.'MAN' ) level = 2

c --- get file access information
      keyname = 'OISST_NAME'
      keyindex = 1
      status = hdrgetkeystr( filename, keyname, keyindex, file )
      call strcompress( file, remove_all, len )

c --- check for error reading info file
      if( status.lt.0 ) then
         call message(
     &                 FUNCTION,
     &                'FAILED: Read of OISST file info . ',
     &                 0, level
     &               )

      else

c ------ issue the OPEN request
         OPEN(
     &         FILE=file(1:len),
     &         UNIT= OISST_UNIT,
     &         STATUS= OISST_STATUS,
     &         FORM= OISST_FORM,
     &         ACCESS= OISST_ACCESS,
     &         RECL=OISST_RECL,
     &         IOSTAT=io_err,
     &         ERR= 9008
     &       )

         call message(
     &                 '--',
     &                'Using OISST file: '// file ,
     &                 0, 4
     &               )

         anc_sst_lun = OISST_UNIT
         goto 170

c ------ Failed to open
9008     continue
         call message(
     &                 FUNCTION,
     &                'FAILED: Open OISST file. ',
     &                 0, level
     &               )

      endif
170   continue
      if( debug.ne.0 ) then
         call strcompress( file, remove_all, len_file )
         write(*,*) '  OISST file: ',file(1:len_file)
      endif


C ANCILLARY FILES: GDAS GLOBAL TEMP AND MOISTURE PROFILES

c --- get the file requirement
      keyname = 'ANC_MET_REQ'
      keyindex = 1
      status = hdrgetkeystr( filename, keyname, keyindex, req )
      if( status.lt.0 ) level=2

c --- get file access information 
      keyname = 'ANC_MET_NAME'
      keyindex = 1
      status = hdrgetkeystr( filename, keyname, keyindex,file )

c --- check for error reading info file
      if( status.lt.0 ) then 
         call message( 
     &                 FUNCTION,
     &                'FAILED: Read of Met Obs file info . ',
     &                 0, level 
     &               )

      else
                   
c ------ issue the OPEN request
         OPEN( 
     &         FILE=file,
     &         UNIT=ANC_MET_UNIT,
     &         STATUS=ANC_MET_STATUS,
     &         FORM=ANC_MET_FORM,
     &         ACCESS=ANC_MET_ACCESS,
     &         RECL=ANC_MET_RECL,
     &         IOSTAT=io_err, 
     &         ERR=9009
     &       ) 

         call message(
     &                 '--',
     &                'Using GDAS Analysis file: '// file ,
     &                 0, 4
     &               )

         anc_met_lun = ANC_MET_UNIT
         goto 180

c ------ Failed to open 
9009     continue 
         call message( 
     &                 FUNCTION,
     &                'FAILED: Could not open GDAS1 file. ',
     &                 0, level 
     &               )

      endif
180   continue
      if( debug.ne.0 ) then
         call strcompress( file, remove_all, len_file )
         write(*,*) '  Met Obs. file: ',file(1:len_file)
      endif
      


C INPUT FILES: CLOUD MASK 

c --- get the file requirement
      keyname = 'MOD35_MASK_REQ'
      keyindex = 1
      status = hdrgetkeystr( filename, keyname, keyindex, req )
      if( status.lt.0 ) req = 'OPTIONAL'
      level = 3
      if( req(1:3).eq.'MAN' ) level = 2

c --- get file access information 
      keyname = 'MOD35_MASK_NAME'
      keyindex = 1
      status = hdrgetkeystr( filename, keyname, keyindex,file )
      call strcompress( file, remove_all, len ) 


c --- check for error reading info file
      if( status.lt.0 ) then 
         call message( 
     &                 FUNCTION,
     &                'FAILED: Read of Cloud Mask file info . ',
     &                 0, level 
     &               )

      else
                   
c ------ issue the OPEN request
         OPEN( 
     &         FILE=file(1:len),
     &         UNIT=MOD35_MASK_UNIT,
     &         STATUS=MOD35_MASK_STATUS,
     &         ACCESS=MOD35_MASK_ACCESS,
     &         RECL=l1b_1km_neles,
     &         IOSTAT=io_err, 
     &         ERR=9010
     &       ) 

         call message(
     &                 '--',
     &                'Using Cloud Mask file: '// file ,
     &                 0, 4
     &               )


         mask_lun = MOD35_MASK_UNIT
         goto 190

c ------ Failed to open 
9010     continue 
         call message( 
     &                 FUNCTION,
     &                'FAILED: Could not open Cloud Mask file. ',
     &                 0, level 
     &               )

      endif
190   continue
      if( debug.ne.0 ) then
         call strcompress( file, remove_all, len_file )
         write(*,*) '  Cloud Mask file: ',file(1:len_file)
      endif
      
C OUTPUT FILES: CLOUD TOP PROPERTIES AND CLOUD PHASE

c --- get the file requirement
      keyname = 'MOD06_CTP_REQ'
      keyindex = 1
      status = hdrgetkeystr( filename, keyname, keyindex, req )
      if( status.lt.0 ) req = 'OPTIONAL'
      level = 3
      if( req(1:3).eq.'MAN' ) level = 2

c --- get file access information 
      keyname = 'MOD06_CTP_NAME'
      keyindex = 1
      status = hdrgetkeystr( filename, keyname, keyindex,file )
      call strcompress( file, remove_all, len ) 


c --- check for error reading info file
      if( status.lt.0 ) then 
         call message( 
     &                 FUNCTION,
     &                'FAILED: Read of CTP output file info . ',
     &                 0, level 
     &               )

      else
                   
c ------ issue the OPEN request
         OPEN( 
     &         FILE=file(1:len),
     &         UNIT=MOD06_CTP_UNIT,
     &         STATUS=MOD06_CTP_STATUS,
     &         ACCESS=MOD06_CTP_ACCESS,
     &         RECL=( l1b_1km_neles / ISAMP ) * 4,
     &         IOSTAT=io_err, 
     &         ERR=9017
     &       ) 

         call message(
     &                 '--',
     &                'Creating Cloud Top Ouput file: '// file ,
     &                 0, 4
     &               )

         mod06ct_lun = MOD06_CTP_UNIT
         goto 260

c ------ Failed to open 
9017     continue 
         call message( 
     &                 FUNCTION,
     &                'FAILED: Could not open output file. ',
     &                 0, level 
     &               )

      endif
260   continue
      if( debug.ne.0 ) then
         call strcompress( file, remove_all, len_file )
         write(*,*) '  CTP Output file: ',file(1:len_file)
      endif

C OUTPUT FILES: CLOUD TOP PROPERTIES AND CLOUD PHASE HEADER FILE

c --- get the file requirement
      keyname = 'MOD06_CTP_REQ'
      keyindex = 1
      status = hdrgetkeystr( filename, keyname, keyindex, req )
      if( status.lt.0 ) req = 'OPTIONAL'
      level = 3
      if( req(1:3).eq.'MAN' ) level = 2

c --- get file access information 
      keyname = 'MOD06_CTP_HDR'
      keyindex = 1
      status = hdrgetkeystr( filename, keyname, keyindex,file )
      call strcompress( file, remove_all, len ) 


c --- check for error reading info file
      if( status.lt.0 ) then 
         call message( 
     &                 FUNCTION,
     &                'FAILED: Read of CTP output header file info . ',
     &                 0, level 
     &               )

      else
                   
c ------ issue the OPEN request
         OPEN( 
     &         FILE=file(1:len),
     &         UNIT=MOD06_HDR_UNIT,
     &         STATUS=MOD06_HDR_STATUS,
     &         ACCESS=MOD06_HDR_ACCESS,
     &         IOSTAT=io_err, 
     &         ERR=9018
     &       ) 

         hdr_lun = MOD06_HDR_UNIT
         goto 261

c ------ Failed to open 
9018     continue 
         call message( 
     &                 FUNCTION,
     &                'FAILED: Could not open output header file. ',
     &                 0, level 
     &               )

      endif
261   continue
      if( debug.ne.0 ) then
         call strcompress( file, remove_all, len_file )
         write(*,*) '  CTP Output header file: ',file(1:len_file)
      endif

C OUTPUT FILES: CLOUD TOP  QUALITY CONTROL 

c --- get the file requirement
      keyname = 'MOD06_QA_REQ'
      keyindex = 1
      status = hdrgetkeystr( filename, keyname, keyindex, req )
      if( status.lt.0 ) req = 'OPTIONAL'
      level = 3
      if( req(1:3).eq.'MAN' ) level = 2

c --- get file access information 
      keyname = 'MOD06_QA_NAME'
      keyindex = 1
      status = hdrgetkeystr( filename, keyname, keyindex,file )
      call strcompress( file, remove_all, len ) 


c --- check for error reading info file
      if( status.lt.0 ) then 
         call message( 
     &                 FUNCTION,
     &                'FAILED: Read of Quality Control file info . ',
     &                 0, level 
     &               )

      else
                   
c ------ issue the OPEN request
         OPEN( 
     &         FILE=file(1:len),
     &         UNIT=MOD06_QA_UNIT,
     &         STATUS=MOD06_QA_STATUS,
     &         ACCESS=MOD06_QA_ACCESS,
     &         RECL=( l1b_1km_neles / ISAMP ),
     &         IOSTAT=io_err, 
     &         ERR=9019
     &       ) 

         call message(
     &                 '--',
     &                'Creating Cloud Top QA Ouput file: '// file ,
     &                 0, 4
     &               )


         qa_lun = MOD06_QA_UNIT
         goto 262

c ------ Failed to open 
9019     continue 
         call message( 
     &                 FUNCTION,
     &                'FAILED: Open CTP Quality Control file. ',
     &                 0, level 
     &               )

      endif
262   continue
      if( debug.ne.0 ) then
         call strcompress( file, remove_all, len_file )
         write(*,*) '  Quality CTP Control file: ',file(1:len_file)
      endif


C OUTPUT FILES: CLOUD TOP QUALITY CONTROL HEADER FILE

c --- get the file requirement
      keyname = 'MOD06_QA_REQ'
      keyindex = 1
      status = hdrgetkeystr( filename, keyname, keyindex, req )
      if( status.lt.0 ) req = 'OPTIONAL'
      level = 3
      if( req(1:3).eq.'MAN' ) level = 2

c --- get file access information 
      keyname = 'MOD06_QA_HDR'
      keyindex = 1
      status = hdrgetkeystr( filename, keyname, keyindex,file )
      call strcompress( file, remove_all, len ) 


c --- check for error reading info file
      if( status.lt.0 ) then 
         call message( 
     &                 FUNCTION,
     &                'FAILED: Read of QC header file info. ',
     &                 0, level 
     &               )

      else
                   
c ------ issue the OPEN request
         OPEN( 
     &         FILE=file(1:len),
     &         UNIT=MOD06_QAHDR_UNIT,
     &         STATUS=MOD06_QAHDR_STATUS,
     &         ACCESS=MOD06_QAHDR_ACCESS,
     &         IOSTAT=io_err, 
     &         ERR=9020
     &       ) 

         qa_hdr_lun = MOD06_QAHDR_UNIT
         goto 263

c ------ Failed to open 
9020     continue 
         call message( 
     &                 FUNCTION,
     &                'FAILED: Open CTP QC header file. ',
     &                 0, level 
     &               )

      endif
263   continue
      if( debug.ne.0 ) then
         call strcompress( file, remove_all, len_file )
         write(*,*) ' CTP QC Header file: ',file(1:len_file)
      endif


C RUNTIME DEBUG FILE

c --- get the file requirement
      keyname = 'DEBUG_REQ'
      keyindex = 1
      status = hdrgetkeystr( filename, keyname, keyindex, req )
      if( status.lt.0 ) req = 'OPTIONAL'
      level = 3
      if( req(1:3).eq.'MAN' ) level = 2

c --- get file access information 
      keyname = 'DEBUG_NAME'
      keyindex = 1
      status = hdrgetkeystr( filename, keyname, keyindex, file )
      call strcompress( file, remove_all, len ) 

c --- check for error reading info file
      if( status.lt.0 ) then 
         call message( 
     &                 FUNCTION,
     &                'FAILED: Read of RunTime Debug file info. ',
     &                 0, level 
     &               )

      else
                   
c ------ issue the OPEN request
         OPEN( 
     &         FILE=file(1:len),
     &         UNIT=DEBUG_UNIT,
     &         STATUS=DEBUG_STATUS,
     &         FORM=DEBUG_FORM,
     &         ACCESS=DEBUG_ACCESS,
     &         IOSTAT=io_err, 
     &         ERR=9030 
     &       ) 

         debug_lun = DEBUG_UNIT
         goto 270

c ------ Failed to open 
9030     continue 
         call message( 
     &                 FUNCTION,
     &                'FAILED: Open RunTime Debug file. ',
     &                 0, level 
     &               )

      endif
270   continue
      if( debug.ne.0 ) then
         call strcompress( file, remove_all, len_file )
         write(*,*) '  Debug file: ',file(1:len_file)
      endif

      return
      end
